@@ -6,8 +6,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef CTHOST_H
-#define CTHOST_H
+#pragma once
 
 #include <QList>
 #include <QString>
@@ -18,6 +17,7 @@ class CTTask;
 class CTVariable;
 class CTCron;
 class CTInitializationError;
+class CrontabWidget;
 
 struct passwd;
 
@@ -49,9 +49,9 @@ public:
 
     /**
      * Apply changes.
-     * return an empty string if no problem
+     * return an empty string if no problem ocurred.
      */
-    CTSaveStatus save();
+    CTSaveStatus save(CrontabWidget *mCrontabWidget);
 
     /**
      * Cancel changes.
@@ -111,4 +111,3 @@ private:
     QString mCrontabBinary;
 };
 
-#endif // CTHOST_H
